@@ -5,5 +5,5 @@ from oscarbot.views import bot_view
 app_name = 'api'
 
 urlpatterns = [
-    path('bot<str:token>/', bot_view),
+    path('bot<str:token>/', bot_view), # deprecated
 ]
