@@ -4,4 +4,6 @@ from oscarbot.router import route
 routes = [
     route('/start', start),
     route('/diagnostic/', first_question),
+    route('/hello/', first_question),
+    route('/hello/<pk>/', first_question),
 ]
