@@ -1,3 +1,5 @@
+from django.conf import settings
+
 from oscarbot.menu import Menu
 from oscarbot.response import TGResponse
 from oscarbot.services import get_bot_model, get_bot_user_model
@@ -5,10 +7,10 @@ from oscarbot.services import get_bot_model, get_bot_user_model
 
 class QuickBot:
 
-    def __init__(self, chat: object, message: str, token: str = None, menu: Menu = None):
+    def __init__(self, user: object, message: str, token: str = None, menu: Menu = None):
         """
         Init QuickBot object for send message to Telegram user
-        @param chat: user id, or username if this user in DB, can be oscarbot.models.User object
+        @param user: user oscarbot.models.User object
         @param message: text message
         @param token: bot token, default get first bot from DB
         @param menu: should be oscarbot.menu.Menu object
@@ -21,24 +23,14 @@ class QuickBot:
             if bot_object:
                 self.token = bot_object.token
 
-        user_model = get_bot_user_model()
-        if isinstance(chat, int):
-            self.chat = chat
-        elif isinstance(chat, str):
-            chat_user = user_model.objects.filter(username=chat).first()
-            if chat_user:
-                self.chat = chat_user.t_id
-        elif isinstance(chat, user_model):
-            chat: user_model
-            self.chat = chat.t_id
-
+        self.user = user
         self.message = message
         self.menu = menu
 
     def send(self):
-        response = TGResponse(message=self.message, menu=self.menu)
+        response = TGResponse(message=self.message, menu=self.menu, need_update=False)
 
         response.send(
             self.token,
-            t_id=self.chat
+            user=self.user
         )
